***Suplee modeling for WRR R&R
*** Uses Jakus et al Nutrient Criterion Data Archived for WRR.dta
*** .dta file variables have labels/codes that can be cross-checked with WRR manuscript     
*** Uses Jakus et al Stata Code for WRR.do
*
gen lakecontact=0
replace lakecontact=1 if q9a==1|q9a==2|q9a==4

gen rivercontact=0
replace rivercontact=1 if q9b==1|q9b==2|q9b==4

replace Income=Income/1000

*Table 2
tab supleedv
tab supleedv if wconsist==1
tab supleedv if sconsist==1

*Table 3
sum wconsist sconsist Q1a_high Q1e_high LakeUser RiverUser Female Income College Age [aweight=newHHWgt]

*Tables 4 and 5
sum photo40 photo110 photo150 photo200 photo240 photo300 photo400 photo1280 [aweight=newHHWgt]
sum photo40 photo110 photo150 photo200 photo240 photo300 photo400 photo1280 if RiverUser==1 

*Table 6 distributions
sum photo40 photo110 photo150 photo200 photo240 photo300 photo400 photo1280 if wconsist==1 [aweight=newHHWgt]
sum photo40 photo110 photo150 photo200 photo240 photo300 photo400 photo1280 if sconsist==1 [aweight=newHHWgt]

*Table 6 Chronbach's alpha
alpha photo40 photo110 photo150 photo200 photo240 photo300 photo400 photo1280
alpha photo40 photo110 photo150 photo200 photo240 photo300 photo400 photo1280 if wconsist==1
alpha photo40 photo110 photo150 photo200 photo240 photo300 photo400 photo1280 if sconsist==1


*Tables 7 and 8 Ordered probit modeling
*Model#1
oprobit supleedv Q1a_high Q1e_high LakeUser RiverUser Female Income College Age [aweight=newHHWgt], vce(robust)
margins, dydx(*)

*Model #2
oprobit supleedv Q1a_high Q1e_high LakeUser RiverUser Female Income College Age sconsist [aweight=newHHWgt], vce(robust)
margins, dydx(*)

*Model #3
oprobit supleedv Q1a_high Q1e_high LakeUser RiverUser Female Income College Age if sconsist==1 [aweight=newHHWgt], vce(robust)
margins, dydx(*)

****ADDITIONAL MODELING FOR REFEREES
 
*Now add "water contact" varibles, all respondents
oprobit supleedv Q1a_high Q1e_high LakeUser lakecontact RiverUser rivercontact Female Income College Age[aweight=newHHWgt], vce(robust)

*Test for collinearity between WQ measures and between User types, all respondents
oprobit supleedv Q1a_high LakeUser RiverUser Female Income College Age [aweight=newHHWgt], vce(robust)
oprobit supleedv Q1e_high LakeUser RiverUser Female Income College Age [aweight=newHHWgt], vce(robust)

oprobit supleedv Q1a_high Q1e_high LakeUser Female Income College Age [aweight=newHHWgt], vce(robust)
oprobit supleedv Q1a_high Q1e_high RiverUser Female Income College Age [aweight=newHHWgt], vce(robust)

*Further tests for multicollinearity
reg supleedv Q1a_high Q1e_high LakeUser RiverUser Female Income College Age [aweight=newHHWgt]

estat vif

corr Q1a_high Q1e_high LakeUser RiverUser Female Income College Age
